@@ -1,7 +1,6 @@
 from django.apps import AppConfig
-from material.frontend.apps import ModuleMixin
 
 
-class CorgyCommonConfig(ModuleMixin, AppConfig):
+class CorgyCommonConfig(AppConfig):
     name = 'corgy_common'
     icon = '<i class="material-icons">settings_applications</i>'
