@@ -442,18 +442,32 @@ class Payroll(MonthBasedMixin, Process):
     employee = models.ForeignKey(
         verbose_name=_('alkalmazott'),
         to=Employment,
+        related_name='employee_processes',
         on_delete=models.CASCADE
     )
 
     timesheet = models.ForeignKey(
-        verbose_name=_('alkalmazott'),
+        verbose_name=_('jelenlét'),
         to=TimeSheet,
+        related_name='timesheet_processes',
         on_delete=models.CASCADE,
         blank=True,
         null=True,
         default=None,
     )
 
+    revenue = models.ForeignKey(
+        verbose_name=_('jövedelem'),
+        to=TimeSheet,
+        related_name='revenue_processes',
+        on_delete=models.CASCADE,
+        blank=True,
+        null=True,
+        default=None,
+    )
+
+
+
     submitted = models.NullBooleanField(
         verbose_name=_('elküldve'),
         help_text=_('hatóság felé elküldve')
